"""Feature flag name constants."""

# Client context flags
FLAG_ALLOW_CLIENT_INFO = "allow-client-info"
FLAG_OPENSPEC = "openspec"

# Workflow flags
FLAG_WORKFLOW = "workflow"
FLAG_WORKFLOW_FILE = "workflow-file"
FLAG_WORKFLOW_CONSENT = "workflow-consent"

# Content format flags
FLAG_CONTENT_FORMAT = "content-format"
FLAG_CONTENT_STYLE = "content-style"

# Development flags
FLAG_GUIDE_DEVELOPMENT = "guide-development"
