---
type: user/information
description: Shows available info subcommands
category: "info"
usage: ":info"
---
{{h1}}Info Commands

Available information commands:
- `{agent.prefix}guide :info/agent` - Shows information about the current MCP agent/client
- `{agent.prefix}guide :info/project` - Shows current project information and configuration
- `{agent.prefix}guide :info/flags` - Shows feature flags and project flags
