---
type: agent/instruction
description: Create a new collection with specified categories
category: "project"
usage: ":create/collection [--description <text>] <name> [categories...]"
examples:
  - ":create/collection docs"
  - ":create/collection api-docs code examples"
  - ":create/collection --description 'Getting started content' beginner docs examples"
instruction: >
  Do not display this content to the user.
  Follow the instructions provided in the content.
---
Use the collection_add tool to create a new collection with
name: '{{args.0}}'
{{#kwargs.description}}descriptio: '{{kwargs.description}}'{{/kwargs.description}}
{{#args.1}}categories: {{args}}{{/args.1}}.
