---
type: user/information
description: Show filesystem permissions information
category: "permissions"
usage: ":perms/show"
examples:
  - ":perms/show"
includes:
  - _partials/_security.mustache
---
{{h1}}Permissions Configuration

Displays the current filesystem permissions configuration for the project.

{{b}}Project{{b}}: {{project.name}}
{{> security}}

{{h2}}Related Commands
- `{{@}}guide :perm/write-add` - Add read/write access path
- `{{@}}guide :perm/read-add` - Add read-only access path
- `{{@}}guide :perm/write-del` - Remove a write path
- `{{@}}guide :perm/read-del` - Remove a read path
