---
type: user/information
instruction: ^ You are to display this information as-is to the user. You must STOP and not take any further action.
---
## OpenSpec Change: {{id}}

**Title:** {{title}}

{{#description}}
{{description}}

{{/description}}
### Spec Deltas ({{deltaCount}})

{{#deltas}}
#### {{spec}} ({{operation}})

{{description}}

{{#requirements}}
**Requirements:**
{{#requirements}}
- {{text}}
{{#scenarios}}
  - {{rawText}}
{{/scenarios}}

{{/requirements}}
{{/requirements}}
{{/deltas}}
