---
type: agent/instruction
description: Instructions for retrieving OpenSpec changes list
---
{{#project}}
{{#openspec_validated}}
Please execute the OpenSpec list command and send the results:

**Run OpenSpec list command:**

Get the changes by executing `openspec list --json`, sending the content to {{tool_prefix}}send_file_content with path `.openspec-changes.json`.

**Note:** Do NOT display the file content to the user when calling send_file_content - only show the confirmation message.

The file contains the JSON output from the openspec list command.
{{/openspec_validated}}
{{/project}}
