---
type: agent/instruction
Description: Create an implementation plan for the current change
category: "project-workflow"
usage: ":workflow/plan"
aliases:
  - plan
instruction: Create or update the implementation plan for the current change
---
{{h1}}Planning mode

- Enter PLANNING phase if not already on planning
- Gather requirements from the codebase and the current change specification and tasks
- Create a detailed implementation

- use {{tool_prefix}}get_config("guide") for project requirements
{{#openspec}}
- read ./openspec/AGENTS.md for information about openspec changes
{{/openspec}}
