---
type: user/information
---
## OpenSpec Error

{{error}}

{{#message}}
{{message}}

{{/message}}
{{#available_changes}}
**Available changes:**
{{#available_changes}}
- {{.}}
{{/available_changes}}
{{/available_changes}}
