---
type: user/information
description: Provide helpful information about the guide prompt
instruction: >
  Display this information to the user.
  Take no further action.
---

{{h1}}ℹ️  Guide MCP Help

{{h2}}Welcome to the Guide MCP help system.

The {{@}}guide prompt may be used both to:

- provide information and instructions to the AI Agent
- provide information to you, the user.

The {{@}}gude prompt also has a built in command system, where commands are prefix by a ':' character: `{{@}}guide {{b}}:{{b}}<command> [arguments]`

To view availalble commands, use:  `{{@}}guide :help`
To view help on commands, use:     `{{@}}guide :help <command>` or `{{@}}guide <command> --help`
