---
type: agent/instruction
description: List all OpenSpec changes in the project
category: "openspec"
usage: ":openspec/list"
requires-openspec: true
includes:
  - ../../_openspec/list-format
---
{{#openspec}}
{{#changes}}
{{>list-format}}
{{/changes}}

{{^changes}}
Run `openspec list --json` and send the result using {{tool_prefix}}send_file_content with path `.openspec-changes.json` to refresh the cache, then re-render this template to display the results.
{{/changes}}
{{/openspec}}
