---
type: agent/instruction
Description: commence implementation
category: "project-workflow"
usage: ":workflow/implement"
aliases:
  - implement
instruction: Execute the implementation plan
---
{{h1}}Implementation mode

- You MUST review the project guidelines, use tool {{tool_prefix}}get_content("guidelines")
- Enter IMPLEMENTATION phase
- Make changes according to the detailed implementation plan

