---
type: agent/instruction
description: Initialise OpenSpec in the current project
category: "openspec"
usage: ":openspec/init"

requires-openspec: true
---
To initialise OpenSpec in this project, please run:

`openspec init`

This will create the required directory structure:
- openspec/project.md
- openspec/changes/
- openspec/specs/

After initialisation, refresh the cache by running `openspec list --json` and sending via {{tool_prefix}}send_file_content with path `.openspec-changes.json`.
