---
type: user/information
description: Shows feature flags and project flags
category: "info"
aliases:
  - flags
usage: ":info/flags"
examples:
  - ":info/flags"
---
{{h1}}Feature Flags

{{h2}}Feature Flags
{{#feature_flag_values}}
{{b}}{{key}}{{b}}: {{value}}
{{/feature_flag_values}}
{{^feature_flag_values}}
None configured
{{/feature_flag_values}}

{{h2}}Project Flags for {{project.name}}
{{#project.project_flag_values}}
{{b}}{{key}}{{b}}: {{value}}
{{/project.project_flag_values}}
{{^project.project_flag_values}}
None configured
{{/project.project_flag_values}}
