---
type: user/information
---
## OpenSpec Changes

{{#has_changes}}
| Name | Status | Progress | Last Modified |
|------|--------|----------|---------------|
{{#sorted_changes}}
| {{name}} | {{status}} | {{progress}} | {{lastModified}} |
{{/sorted_changes}}
{{/has_changes}}
{{^has_changes}}
*No changes found*
{{/has_changes}}
