---
type: user/information
description: Show help information
category: "system"
aliases:
  - "?"
  - "h"
usage: ":help [command] [--table|-t]"
examples:
  - ":help"
  - ":? create"
  - ":h list"
  - ":help --table"
instruction: Display this information to the user. Take no further action.
---
{{h1}}ℹ️  Command Help
{{#args}}
{{#command_help}}
{{h2}}{{name}}{{#aliases}} ({{#first}}{{/first}}:`{{value}}`{{#last}}{{/last}}{{^last}}, {{/last}}{{/aliases}})

{{description}}

{{#usage}}
**Usage:** `{{usage}}`
{{/usage}}

{{#examples}}
{{h3}}Examples
{{#.}}
- `{{.}}`
{{/.}}
{{/examples}}
{{/command_help}}
{{^command_help}}
Command not found: {{.}}
{{/command_help}}
{{/args}}
{{^args}}
{{#command_categories}}
{{#kwargs.table}}
**{{title}}**
| Command | Description |
|---------|-------------|
{{#commands}}
| `{{@}}guide :{{name}}`{{#aliases}} (:`{{value}}`){{/aliases}} | {{description}} |
{{/commands}}

{{/kwargs.table}}
{{^kwargs.table}}
{{h2}}{{title}}
{{#commands}}
- `{{@}}guide :{{name}}` {{#aliases}}{{#first}}({{/first}}:`{{value}}`{{#last}}){{/last}}{{^last}}, {{/last}}{{/aliases}} - {{description}}
{{/commands}}

{{/kwargs.table}}
{{/command_categories}}
{{/args}}
