---
type: agent/instruction
description: Create a new project category
category: "project"
usage: ":create/category [--dir <path>] [--patterns <pattern>...] [--description <text>] <name>"
examples:
  - ":create/category docs"
  - ":create/category --dir documentation --patterns '{{*}}.md' '{{*}}.rst' api-docs"
  - ":create/category --description 'Test files' tests"
instruction: >
  Do not display this content to the user.
  Follow the instructions provided in the content.
---
Use the category_add tool to create a new category with:
name: '{{args.0}}'
{{#kwargs.dir}}directory: '{{kwargs.dir}}'{{/kwargs.dir}}
{{#kwargs.patterns}}patterns: {{kwargs.patterns}}{{/kwargs.patterns}}
{{#kwargs.description}}description: '{{kwargs.description}}'{{/kwargs.description}}.
