---
type: user/information
description: Shows current project information and configuration
category: "info"
usage: ":info/project [--verbose|-v]"
aliases: ["project"]
includes:
  - ../_partials/project
---
{{h1}}Project Information

{{>project}}

