---
type: agent/instruction
description: Instructions for checking OpenSpec CLI availability
---
{{#project}}
{{^openspec_validated}}
Please check if the OpenSpec CLI is available on your system and send the result using the {{tool_prefix}}send_command_location tool:

**Check for OpenSpec CLI:**
- Use `which openspec` (Unix/Linux/macOS) or `where openspec` (Windows)
- Send the command location (or empty string if not found) using: `{{tool_prefix}}send_command_location` with:
  - command: "openspec"
  - location: full path to openspec command, or null if not found

**Example:**
```
{{tool_prefix}}send_command_location(command="openspec", location="/usr/local/bin/openspec")
```

Or if not found:
```
{{tool_prefix}}send_command_location(command="openspec", location=null)
```
{{/openspec_validated}}
{{/project}}
