---
type: agent/information
---
{{h1}}MCP Atlassian Context Instructions

{{b}}Project Type:{{b}} Kanban
{{b}}Approach:{{b}} Minimalist, SOLID, YAGNI*
{{b}}Issue Management{{b}}: This is a JIRA managed project

{{h2}}Project Workflow Directories

See Guilde MCP: [guide_]category_content("context", "openspec") tool

{{h2}}Workflow

{{b}}SPECIFICATIONS{{b}}
After discussion with the user, a specification must be established and a corresponding JIRA issue created.
If the tasks has already been created, ask the user for the issue Id.
Ensure that the description must include:
  - A concise summary of the specification (issuesubject)
  - A description what is to be done, and why - motivations
  - Context and background
  - Objectives, description of the end result
  - Pre-requisites and requirements for implementation
  - Assumptions
  - A list of acceptance criteria

- The results of the description should be uploaded as the body of the issue itself.
- Acceptance criteria are to be made

{{b}}PLANNING{{b}}
Based on this description, when ready to commence the implementation, and all of the pre-requisites are satisfied and implementation plan must be added as the first comment in the JIRA issue.

It should provide a broad outline of what work is to be done, in what order, and how it will be tested.
It should comply with the tasks format and methodology required for this project.

- A checklist should be added if required.
- These should be task based.
- It should be ordered.
- It should be short, but be a complete testable unit.

If using TDD, the checklist should break down tasks based on the pattern:
  - RED(Test) -> GREEN(Implement) -> REFACTOR(Improve)
