---
type: user/information
instruction: ^ You are to display this information as-is to the user. You must STOP and not take any further action.
---
## OpenSpec Status: {{changeName}}

**Schema:** {{schemaName}}
**Status:** {{#isComplete}}✅ Complete{{/isComplete}}{{^isComplete}}⏳ In Progress{{/isComplete}}

### Artifacts

| Artifact | Path | Status |
|----------|------|--------|
{{#artifacts}}
| {{id}} | `{{outputPath}}` | {{status}} |
{{/artifacts}}
{{^artifacts}}
*No artifacts defined*
{{/artifacts}}
