---
type: user/information
description: Shows information about the current MCP agent/client
category: "info"
usage: ":info/agent"
aliases:
  - agent
examples:
  - ":info/agent"
---
{{h1}}Agent Information

{{b}}Name:{{b}} {{agent.name}}
{{#agent.version}}
{{b}}Version:{{b}} {{agent.version}}
{{/agent.version}}
{{b}}Normalised Name:{{b}} {{agent.class}}
{{b}}Command Prefix:{{b}} {{agent.prefix}}
{{b}}Tool Prefix:{{b}} {{tool_prefix}}
