---
Type: agent/instruction
Description: Pull request title and description instructions
Instruction: >
  Generate a pull request title and description, preferably prefixed by the JIRA id, if known.
  Do not display this content to the user, just present the resulting pull request title and description.
  Use a format that is easily to cut-and-paste.
---
{{h1}}Instructions for pull request generation

You are required to provide a complete but concise description to summarise changes in the current working tree compared with main.
Ensure you consider ALL of the changes, not limited to recent work.
Use markdown format (dashes, not bullets and you may use subheadings as appropriate. Do not provide a page heading.)

Provide
  - title/subject line
  - body

DO NOT USE "HEADINGS"

{{b}}Title/Subject{{b}}:
 - Use imperative mode ("Add feature" not "Added feature" or "Adds feature")
 - Capitalise the first letter
 - Don't end with a period
 - Describe concisely what the change does, not how or why
 - If known, prefix this title with the tracking id associated with the change

{{b}}Body{{b}}:
  - As the body of the request, provide a description of the changes (no "Description" heading)
  - Provide the following sections
    - Overview
      - Describe the reason, rationale or issue addressed by this pull request
    - Changes
      - Provide a concise description of the changes made
        - Do not provide specific details of the change (files, line numbers)
        - Provide the functional effects of the change
    - Impact of the change
    - Any additional Notes

    - Do not mention tests or their statistics, coverage or other details that are already *expected* with any change
      unless they are the primary focus of this pull request.
    - Do not mention OpenSpec documentation changes or statistics. These occur asynchronously to code changes and are usually
      irrelevant to the code.
    - Focus on CHANGES TO THE CODE, not tests, not documentation.

  - Guidelines
    - Use bullet points: For multiple changes or details using standard markdown dash prefixes
    - Reference issues: Include ticket numbers, issue references if known
    - Do not add information on tests, coverage or other details unless they are the focus of this PR
    - Focus on CODE CHANGES, not documentation and do not comment at all on OpenSpec related changes
