---
type: user/information
description: Format OpenSpec changes list for display
instruction: ^ You are to display this information as-is to the user. You must STOP and not take any further action.
---
{{#openspec}}
{{#changes}}
## OpenSpec Changes

{{#in_progress.0}}
### In Progress
{{#in_progress}}
- `{{name}}` ({{progress}}) - {{humanized_date}}
{{/in_progress}}

{{/in_progress.0}}
{{#draft.0}}
### Draft
{{#draft}}
- `{{name}}` - {{humanized_date}}
{{/draft}}

{{/draft.0}}
{{#complete.0}}
### Complete
{{#complete}}
- `{{name}}` ({{progress}}) - {{humanized_date}}
{{/complete}}
{{/complete.0}}
{{/changes}}
{{/openspec}}
