---
type: user/information
description: Add permission to read external directories
category: "permissions"
usage: ":perm/read-add <path1> [<path2> ...]"
examples:
  - ":perm/read-add ~/Projects/"
  - ":perm/read-add ~/tmp/ ~/Documents/"
---
{{#if args}}
{{h1}}Add Read Permission

Please add read permission for the following path(s):
{{#each args}}
- `{{this}}`
{{/each}}

Use the `permission_read_add` tool with these paths as arguments.
{{else}}
{{h1}}Add Read Permission

Add permission to read from external directories.

{{h2}}Usage
```
:perm/read-add <path1> [<path2> ...]
```

{{h2}}Examples
```
:perm/read-add ~/Projects/
:perm/read-add ~/tmp/ ~/Documents/
```

{{h2}}Related Commands
- `:perm/write-add` - Add write permission
- `:perm` - Show current permissions
- `:perm/read-del` - Remove read permission
{{/if}}
