---
type: agent/information
---

{{h1}}Instructions to list pending issues

To list pending issues, examine the .issue queue, which should list issues that have previously been discussed and queued as a work item.

- Read the `.issue` file and determine the list
- Briefly check the referenced plans and determine if any have been completed (most likely the first listed)
- Provide a summary of each queued item, it's status (PENDING|COMPLETED) and the title of each against the referenced filename.
