---
type: agent/instruction
description: Instructions as a reminder to send {{workflow.file}} content to the mcp server when it changes.
requires-workflow: true
---
You MUST send the COMPLETE content of {{workflow.file}} using the {{tool_prefix}}send_file_content tool whenever it is updated.
