---
type: agent/information
---

** Instructions for specification generation

You are tasked with providing a specification to embody your understanding of a problem or feature.
Use markdown format (dashes, not bullets and use subheadings as appropriate).

- Do NOT produced an implemenation plan. If the user accepts this plan, it may be the next step.
- This document must be focused on WHAT needs to be achieved, not HOW.
- It should provide the following sections:
  - Objectives / Current Issues
    - List the objectives to be outlined in this specification
  - Requirements
    - Functional requirements
    - Dependencies (if any)
    - Constraints (if any)
    - Assumptions
    - Non-functional requirements
    - Breaking changes (if any)
- Scope
  - Be clear about the scope, what is to be achieved
  - out of scope
- Success Criteria
  - Acceptance Criteria
- Risks

Other potential sections

- Formats (if any)
- Classification
- Error Handling
- Side Effects
- Breaking Changes
- Open Questions (uncertainties and required decisions)
- other sections as required
