---
type: agent/information
---
{{h1}}Task completion instructions

The current issue may be complete and requires running some cleanup tasks.

As a final check, ensure that:

- The checklist items in the task plan have been marked as complete.
- Archive the plan by moving it to `.todo/done`
- Remove the plan path from the `.issue` file

Finally, transition to DISCUSSION phase by removing the `.consent` file
