---
type: agent/instruction
description: Show details for a specific OpenSpec change
category: "openspec"
usage: ":openspec/show [<change-id>]"
requires-openspec: true
includes:
  - ../../_openspec/show-format
---
{{#openspec}}
{{#show}}
{{>show-format}}
{{/show}}

{{^show}}
{{#args.0.value}}
Run `openspec show {{args.0.value}} --json` and send the result using {{tool_prefix}}send_file_content with path `.openspec-show.json` to refresh the cache, then re-render this template to display the results.
{{/args.0.value}}
{{^args.0.value}}
{{#workflow.issue}}
Run `openspec show {{workflow.issue}} --json` and send the result using {{tool_prefix}}send_file_content with path `.openspec-show.json` to refresh the cache, then re-render this template to display the results.
{{/workflow.issue}}
{{^workflow.issue}}
**Error:** No change-id provided and no current workflow issue set.

Usage: `{{agent.prefix}}guide :openspec/show <change-id>`

Example: `{{agent.prefix}}guide :openspec/show add-client-documents`

Or set a workflow issue first with `{{agent.prefix}}guide :workflow/issue <change-id>`
{{/workflow.issue}}
{{/args.0.value}}
{{/show}}
{{/openspec}}
