---
type: agent/instruction
---

📈 **Phase Status Check**

- `.consent` exists? → contains `check`? → **CHECK** else **IMPLEMENTATION**
- No `.consent`? → non-empty `.issue` exists? → **PLANNING** else **DISCUSSION**

Display the phase status and return to the prompt.
